LinearEquation class

直線方程式 cy = ax + b Linear equation cy = ax + b

Constructors

LinearEquation({required double a, required double b, required double c})

Properties

a double
final
b double
final
c double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited