CircleEquation class
圓形方程式 (x-h)^2 + (y-k)^2 = r^2, 圓心(h, k), 半徑r Circle equtaion (x-h)^2 + (y-k)^2 = r^2, circumcenter (h, k), radius r
Constructors
- CircleEquation({required double h, required double k, required double r})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited